#
# spec file for package google-gson
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           google-gson
Version:        2.8.9
Release:        8.1
Summary:        Java lib for conversion of Java objects into JSON representation
License:        Apache-2.0
URL:            https://github.com/google/gson
Source0:        https://github.com/google/gson/archive/gson-parent-%{version}.tar.gz
Source1:        %{name}-build.tar.xz
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  glassfish-annotation-api
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsr-305
# The automatic requires would be java-headless >= 9, but the
# binaries are java 8 compatible
%define __requires_exclude java-headless
Requires:       java-headless >= 1.8
BuildArch:      noarch

%description
Gson is a Java library that can be used to convert a Java object into its
JSON representation. It can also be used to convert a JSON string into an
equivalent Java object. Gson can work with arbitrary Java objects including
pre-existing objects that you do not have source-code of.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n gson-gson-parent-%{version} -a1

%build
mkdir -p lib
build-jar-repository -s lib jsr-305 glassfish-annotation-api
ant package javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 gson/target/gson-%{version}.jar %{buildroot}%{_javadir}/%{name}/gson.jar
install -pm 0644 extras/target/gson-extras-%{version}.jar %{buildroot}%{_javadir}/%{name}/gson-extras.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%mvn_install_pom gson/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/gson.pom
%add_maven_depmap %{name}/gson.pom %{name}/gson.jar
%mvn_install_pom extras/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/gson-extras.pom
%add_maven_depmap %{name}/gson-extras.pom %{name}/gson-extras.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
for i in gson extras; do
  cp -r ${i}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/${i}
done
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc README.md CHANGELOG.md UserGuide.md

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE

%changelog
* Fri Mar 28 2025 Fridrich Strba <fstrba@suse.com>
- Rewrite the build system for ant to avoid potential build cycles
  with upcoming Maven 4
- Removed patches:
  * no-template-plugin.patch
  * osgi-export-internal.patch
    + factored into the ant build already
* Mon Apr 29 2024 Fridrich Strba <fstrba@suse.com>
- The binaries are compatible with java 1.8
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Apr  1 2022 Fridrich Strba <fstrba@suse.com>
- Build with Java >= 9 in order to produce a modular jar by
  compiling the module-info.java sources with all other classes
  built with release 8 and still compatible with Java 8
- Removed patch:
  * allow-build-with-java8.patch
    + not needed in this setting
* Thu Mar 31 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.8.9 (jsc#SLE-24261)
  * Changes
    + Make OSGi bundle's dependency on sun.misc optional.
    + Deprecate Gson.excluder() exposing internal Excluder class.
    + Prevent Java deserialization of internal classes.
    + Improve number strategy implementation.
    + Fix LongSerializationPolicy null handling being inconsistent
    with Gson.
    + Support arbitrary Number implementation for Object and Number
    deserialization.
    + Bump proguard-maven-plugin from 2.4.0 to 2.5.1.
    + Don't exclude static local classes.
    + Fix RuntimeTypeAdapterFactory depending on internal Streams
    class.
    + Improve Maven build.
    + Make dependency on java.sql optional.
  * fixes bsc#1199064, CVE-2022-25647
- Removed patch:
  * sun-misc.patch
    + integrated upstream
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Tue Oct 19 2021 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.8.8
  * Changes
    + Fixed issue with recursive types.
    + Better behaviour with Java 9+ and Unsafe if there is a
    security manager.
    + EnumTypeAdapter now works better when ProGuard has obfuscated
    enum fields.
- Removed patch:
  * fix-test.patch
    + integrated upstream
- Modified patches:
  * no-template-plugin.patch
  * osgi-export-internal.patch
    + rediff to changed context
- Added patches:
  * allow-build-with-java8.patch
    + lower the unnecessary requirement of Java 9
  * sun-misc.patch
    + make import of sun.misc optional since not all versions of
    jdk export it
* Fri Nov  1 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of google-gson 2.8.5
